summaryrefslogtreecommitdiffstats
path: root/libkdepim/kregexp3.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kregexp3.h')
-rw-r--r--libkdepim/kregexp3.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/libkdepim/kregexp3.h b/libkdepim/kregexp3.h
index 34473029..40c7681d 100644
--- a/libkdepim/kregexp3.h
+++ b/libkdepim/kregexp3.h
@@ -29,17 +29,17 @@
your version.
*/
-#include <qglobal.h>
-#include <qregexp.h>
+#include <tqglobal.h>
+#include <tqregexp.h>
-#include <qstring.h>
+#include <tqstring.h>
#include <kdepimmacros.h>
/** @short A QRegExp (Qt3.x) with a replace() method.
This class is simply there to provide a namespace for some nice
- enhancements of the mighty QRegExp (Qt3 version) regular
+ enhancements of the mighty TQRegExp (Qt3 version) regular
expression engine, namely the method replace(), which can be
used to do search-and-replace like one is used to from perl or sed.
@@ -80,15 +80,15 @@ class KDE_EXPORT KRegExp3 : public QRegExp
{
public:
KRegExp3()
- : QRegExp() {}
- KRegExp3( const QString & pattern,
+ : TQRegExp() {}
+ KRegExp3( const TQString & pattern,
bool caseSensitive = TRUE,
bool wildcard = FALSE )
- : QRegExp( pattern, caseSensitive, wildcard ) {}
- KRegExp3( const QRegExp & rx )
- : QRegExp( rx ) {}
+ : TQRegExp( pattern, caseSensitive, wildcard ) {}
+ KRegExp3( const TQRegExp & rx )
+ : TQRegExp( rx ) {}
KRegExp3( const KRegExp3 & rx )
- : QRegExp( (QRegExp)rx ) {}
+ : TQRegExp( (TQRegExp)rx ) {}
/** Replaces each matching subpattern in @p str with
@p replacementStr, inserting captured substrings for
@@ -105,7 +105,7 @@ public:
Equivalent to the /g switch to perl's s/// operator.
@return The modified string.
*/
- QString replace( const QString & str,
- const QString & replacementStr,
+ TQString replace( const TQString & str,
+ const TQString & replacementStr,
int start=0, bool global=TRUE );
};
@@ -29,17 +29,17 @@
#include <kdepimmacros.h>
-/** @short A QRegExp (Qt3.x) with a replace() method.
+/** @short A TQRegExp (Qt3.x) with a replace() method.
This class is simply there to provide a namespace for some nice